==> kadaster-gds2-2.3-sources.jar: nl/logius/digikoppeling/gb/_2010/_10/ObjectFactory.java <==

package nl.logius.digikoppeling.gb._2010._10;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.logius.digikoppeling.gb._2010._10 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _DigikoppelingExternalDatareferences_QNAME = new QName("http://www.logius.nl/digikoppeling/gb/2010/10", "digikoppeling-external-datareferences");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.logius.digikoppeling.gb._2010._10
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DataReference }
     * 
     */
    public DataReference createDataReference() {
        return new DataReference();
    }

    /**
     * Create an instance of {@link DataReference.Transport }
     * 
     */
    public DataReference.Transport createDataReferenceTransport() {
        return new DataReference.Transport();
    }

    /**
     * Create an instance of {@link ExternalDataReference }
     * 
     */
    public ExternalDataReference createExternalDataReference() {
        return new ExternalDataReference();
    }

    /**
     * Create an instance of {@link DatetimeType }
     * 
     */
    public DatetimeType createDatetimeType() {
        return new DatetimeType();
    }

    /**
     * Create an instance of {@link ChecksumType }
     * 
     */
    public ChecksumType createChecksumType() {
        return new ChecksumType();
    }

    /**
     * Create an instance of {@link UrlType }
     * 
     */
    public UrlType createUrlType() {
        return new UrlType();
    }

    /**
     * Create an instance of {@link Md5String }
     * 
     */
    public Md5String createMd5String() {
        return new Md5String();
    }

    /**
     * Create an instance of {@link AnyString }
     * 
     */
    public AnyString createAnyString() {
        return new AnyString();
    }

    /**
     * Create an instance of {@link DataReference.Lifetime }
     * 
     */
    public DataReference.Lifetime createDataReferenceLifetime() {
        return new DataReference.Lifetime();
    }

    /**
     * Create an instance of {@link DataReference.Content }
     * 
     */
    public DataReference.Content createDataReferenceContent() {
        return new DataReference.Content();
    }

    /**
     * Create an instance of {@link DataReference.Transport.Location }
     * 
     */
    public DataReference.Transport.Location createDataReferenceTransportLocation() {
        return new DataReference.Transport.Location();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExternalDataReference }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExternalDataReference }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", name = "digikoppeling-external-datareferences")
    public JAXBElement<ExternalDataReference> createDigikoppelingExternalDatareferences(ExternalDataReference value) {
        return new JAXBElement<ExternalDataReference>(_DigikoppelingExternalDatareferences_QNAME, ExternalDataReference.class, null, value);
    }

}

==> kadaster-gds2-3.1-sources.jar: nl/logius/digikoppeling/gb/_2010/_10/ObjectFactory.java <==

package nl.logius.digikoppeling.gb._2010._10;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.logius.digikoppeling.gb._2010._10 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _DigikoppelingExternalDatareferences_QNAME = new QName("http://www.logius.nl/digikoppeling/gb/2010/10", "digikoppeling-external-datareferences");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.logius.digikoppeling.gb._2010._10
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DataReference }
     * 
     */
    public DataReference createDataReference() {
        return new DataReference();
    }

    /**
     * Create an instance of {@link DataReference.Transport }
     * 
     */
    public DataReference.Transport createDataReferenceTransport() {
        return new DataReference.Transport();
    }

    /**
     * Create an instance of {@link ExternalDataReference }
     * 
     */
    public ExternalDataReference createExternalDataReference() {
        return new ExternalDataReference();
    }

    /**
     * Create an instance of {@link DatetimeType }
     * 
     */
    public DatetimeType createDatetimeType() {
        return new DatetimeType();
    }

    /**
     * Create an instance of {@link ChecksumType }
     * 
     */
    public ChecksumType createChecksumType() {
        return new ChecksumType();
    }

    /**
     * Create an instance of {@link UrlType }
     * 
     */
    public UrlType createUrlType() {
        return new UrlType();
    }

    /**
     * Create an instance of {@link Md5String }
     * 
     */
    public Md5String createMd5String() {
        return new Md5String();
    }

    /**
     * Create an instance of {@link AnyString }
     * 
     */
    public AnyString createAnyString() {
        return new AnyString();
    }

    /**
     * Create an instance of {@link DataReference.Lifetime }
     * 
     */
    public DataReference.Lifetime createDataReferenceLifetime() {
        return new DataReference.Lifetime();
    }

    /**
     * Create an instance of {@link DataReference.Content }
     * 
     */
    public DataReference.Content createDataReferenceContent() {
        return new DataReference.Content();
    }

    /**
     * Create an instance of {@link DataReference.Transport.Location }
     * 
     */
    public DataReference.Transport.Location createDataReferenceTransportLocation() {
        return new DataReference.Transport.Location();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExternalDataReference }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExternalDataReference }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", name = "digikoppeling-external-datareferences")
    public JAXBElement<ExternalDataReference> createDigikoppelingExternalDatareferences(ExternalDataReference value) {
        return new JAXBElement<ExternalDataReference>(_DigikoppelingExternalDatareferences_QNAME, ExternalDataReference.class, null, value);
    }

}
